#
# Cookbook:: esh_zfs
# Recipe:: default
#
# Copyright:: 2022, https://easyself.host
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

template '/usr/local/bin/zfs-scrub' do
  owner 'root'
  group 'root'
  mode '0500'
  variables hc_url: node['esh']['zfs']['scrub']['hc_url'],
    pools: node['esh']['zfs']['pools']
  action :create
end

systemd_unit 'zfs-scrub.service' do
  content <<~EOU
  [Unit]
  Description=zfs scrub pools

  [Service]
  Nice=19
  IOSchedulingClass=idle
  KillSignal=SIGINT
  ExecStart=/usr/local/bin/zfs-scrub

  [Install]
  WantedBy=multi-user.target
  EOU
  action [:create, :enable]
end

systemd_unit 'zfs-scrub.timer' do
  content <<~EOU
  [Unit]
  Description=Monthly zpool scrub

  [Timer]
  OnCalendar=monthly
  RandomizedDelaySec=86400
  Persistent=true

  [Install]
  WantedBy=multi-user.target
  EOU
  action [:create, :enable, :start]
end
